@@ -1,7 +1,13 @@
+/**
+ * SPDX-FileCopyrightText: 2020-2023 Osimis S.A., 2024-2024 Orthanc Team SRL, 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 /**
  * Python plugin for Orthanc
  * Copyright (C) 2020-2023 Osimis S.A., Belgium
- * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -20,6 +26,8 @@
 
 #include "OnChangeCallback.h"
 
+#include "PythonHeaderWrapper.h"
+
 #include "../Resources/Orthanc/Plugins/OrthancPluginCppWrapper.h"
 #include "ICallbackRegistration.h"
 #include "PythonString.h"
@@ -192,14 +200,13 @@ static void ChangesWorker()
           std::string traceback;
           if (lock.HasErrorOccurred(traceback))
           {
-            OrthancPlugins::LogError("Error in the Python on-change callback, "
-                                     "traceback:\n" + traceback);
+            ORTHANC_PLUGINS_LOG_ERROR("Error in the Python on-change callback, traceback:\n" + traceback);
           }
         }
         catch (OrthancPlugins::PluginException& e)
         {
-          OrthancPlugins::LogError("Error during Python on-change callback: " +
-                                   std::string(e.What(OrthancPlugins::GetGlobalContext())));
+          ORTHANC_PLUGINS_LOG_ERROR("Error during Python on-change callback: " +
+                                    std::string(e.What(OrthancPlugins::GetGlobalContext())));
         }
       }
     }
