@@ -1,7 +1,13 @@
+/**
+ * SPDX-FileCopyrightText: 2020-2023 Osimis S.A., 2024-2024 Orthanc Team SRL, 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 /**
  * Python plugin for Orthanc
  * Copyright (C) 2020-2023 Osimis S.A., Belgium
- * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -54,8 +60,7 @@ PythonFunction::PythonFunction(PythonLock& lock,
         !PyCallable_Check(func_->GetPyObject()))
     {
       func_.reset();  // Not such a function
-      OrthancPlugins::LogWarning("Missing Python function: " + module.GetName() +
-                                 "." + name + "()");
+      ORTHANC_PLUGINS_LOG_WARNING("Missing Python function: " + module.GetName() + "." + name + "()");
     }
   }
 }
@@ -68,7 +73,7 @@ PythonObject* PythonFunction::Call()
   std::string error;
   if (lock_.HasErrorOccurred(error))
   {
-    OrthancPlugins::LogError("Python exception has occurred, traceback:\n" + error);
+    ORTHANC_PLUGINS_LOG_ERROR("Python exception has occurred, traceback:\n" + error);
     ORTHANC_PLUGINS_THROW_EXCEPTION(Plugin);
   }
   else
@@ -85,7 +90,7 @@ PythonObject* PythonFunction::Call(const PythonObject& args)
   std::string error;
   if (lock_.HasErrorOccurred(error))
   {
-    OrthancPlugins::LogError("Python exception has occurred, traceback:\n" + error);
+    ORTHANC_PLUGINS_LOG_ERROR("Python exception has occurred, traceback:\n" + error);
     ORTHANC_PLUGINS_THROW_EXCEPTION(Plugin);
   }
   else
