@@ -1,7 +1,13 @@
+/**
+ * SPDX-FileCopyrightText: 2020-2023 Osimis S.A., 2024-2024 Orthanc Team SRL, 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
 /**
  * Python plugin for Orthanc
  * Copyright (C) 2020-2023 Osimis S.A., Belgium
- * Copyright (C) 2021-2023 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
+ * Copyright (C) 2024-2024 Orthanc Team SRL, Belgium
+ * Copyright (C) 2021-2024 Sebastien Jodogne, ICTEAM UCLouvain, Belgium
  *
  * This program is free software: you can redistribute it and/or
  * modify it under the terms of the GNU Affero General Public License
@@ -129,7 +135,7 @@ PyObject* PythonObject::Release()
   }
   else
   {
-    OrthancPlugins::LogError("Cannot release a NULL or borrowed reference");
+    ORTHANC_PLUGINS_LOG_ERROR("Cannot release a NULL or borrowed reference");
     ORTHANC_PLUGINS_THROW_EXCEPTION(InternalError);
   }
 }
